@@ -1,6 +1,6 @@
 zelig2ls <- function(formula, model, data, M, ...) {
   mf <- match.call(expand.dots = TRUE)
-  mf$model <- mf$M <- NULL
-  mf[[1]] <- as.name("lm")
+  mf$model <- mf$M <- mf$robust <- NULL
+  mf[[1]] <- lm
   as.call(mf)
 }
